@@ -1,4 +1,4 @@
-/*  encrypt.c,v 1.5 2005/05/20 01:17:28 eagle Exp
+/*  $Id: encrypt.c 2293 2005-12-03 19:51:13Z rra $
 **
 **  Routines to send and receive encrypted chunks using the krb_mk_priv and
 **  krb_rd_priv routines.  A chunk consists of a network long "n" (the length)
@@ -22,6 +22,7 @@
 # include <krb.h>
 #endif
 
+#include "encrypt.h"
 #include "kftgt.h"
 
 int 
@@ -38,7 +39,8 @@ send_encrypted_chunk(
       int elen;
       KRB_UINT32 nlen;
 
-      elen = krb_mk_priv(in, buffer, in_len, sched, session, sender, receiver);
+      elen = krb_mk_priv((unsigned char *) in, (unsigned char *) buffer,
+                         in_len, sched, session, sender, receiver);
 
       if (elen >KFTGT_MAX_BUFFER) return -1;
 
@@ -79,7 +81,8 @@ receive_encrypted_chunk(
 
      /* decrypt */
      
-     status = krb_rd_priv(buffer,elen,sched,session,sender,receiver,m_data);
+     status = krb_rd_priv((unsigned char *) buffer,elen,sched,session,sender,
+                          receiver,m_data);
 
      if (status != KSUCCESS) return -1;
      else return m_data->app_length;
